==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/hybridnetwork/kotlin/inputs/SiteNetworkServicePropertiesFormatArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridnetwork.kotlin.inputs

import com.pulumi.azurenative.hybridnetwork.inputs.SiteNetworkServicePropertiesFormatArgs.builder
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Site network service properties.
 * @property desiredStateConfigurationGroupValueReferences The goal state of the site network service resource. This has references to the configuration group value objects that describe the desired state of the site network service.
 * @property managedResourceGroupConfiguration Managed resource group configuration.
 * @property networkServiceDesignVersionResourceReference The network service design version resource reference.
 * @property siteReference The site details
 */
public data class SiteNetworkServicePropertiesFormatArgs(
    public val desiredStateConfigurationGroupValueReferences:
    Output<Map<String, ReferencedResourceArgs>>? = null,
    public val managedResourceGroupConfiguration: Output<ManagedResourceGroupConfigurationArgs>? =
        null,
    public val networkServiceDesignVersionResourceReference:
    Output<Either<OpenDeploymentResourceReferenceArgs, SecretDeploymentResourceReferenceArgs>>? =
        null,
    public val siteReference: Output<ReferencedResourceArgs>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.hybridnetwork.inputs.SiteNetworkServicePropertiesFormatArgs> {
    override fun toJava():
        com.pulumi.azurenative.hybridnetwork.inputs.SiteNetworkServicePropertiesFormatArgs =
        com.pulumi.azurenative.hybridnetwork.inputs.SiteNetworkServicePropertiesFormatArgs.builder()
            .desiredStateConfigurationGroupValueReferences(
                desiredStateConfigurationGroupValueReferences?.applyValue({ args0 ->
                    args0.map({ args0 -> args0.key.to(args0.value.let({ args0 -> args0.toJava() })) }).toMap()
                }),
            )
            .managedResourceGroupConfiguration(
                managedResourceGroupConfiguration?.applyValue({ args0 ->
                    args0.let({ args0 -> args0.toJava() })
                }),
            )
            .networkServiceDesignVersionResourceReference(
                networkServiceDesignVersionResourceReference?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0.let({ args0 -> args0.toJava() }) }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .siteReference(siteReference?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [SiteNetworkServicePropertiesFormatArgs].
 */
@PulumiTagMarker
public class SiteNetworkServicePropertiesFormatArgsBuilder internal constructor() {
    private var desiredStateConfigurationGroupValueReferences:
        Output<Map<String, ReferencedResourceArgs>>? = null

    private var managedResourceGroupConfiguration: Output<ManagedResourceGroupConfigurationArgs>? =
        null

    private var networkServiceDesignVersionResourceReference:
        Output<Either<OpenDeploymentResourceReferenceArgs, SecretDeploymentResourceReferenceArgs>>? =
        null

    private var siteReference: Output<ReferencedResourceArgs>? = null

    /**
     * @param value The goal state of the site network service resource. This has references to the configuration group value objects that describe the desired state of the site network service.
     */
    @JvmName("ppdfmjolvfnodhdn")
    public suspend
    fun desiredStateConfigurationGroupValueReferences(`value`: Output<Map<String, ReferencedResourceArgs>>) {
        this.desiredStateConfigurationGroupValueReferences = value
    }

    /**
     * @param value Managed resource group configuration.
     */
    @JvmName("cajurxvsfdifngbp")
    public suspend
    fun managedResourceGroupConfiguration(`value`: Output<ManagedResourceGroupConfigurationArgs>) {
        this.managedResourceGroupConfiguration = value
    }

    /**
     * @param value The network service design version resource reference.
     */
    @JvmName("jusqmyxgkhigleko")
    public suspend
    fun networkServiceDesignVersionResourceReference(`value`: Output<Either<OpenDeploymentResourceReferenceArgs, SecretDeploymentResourceReferenceArgs>>) {
        this.networkServiceDesignVersionResourceReference = value
    }

    /**
     * @param value The site details
     */
    @JvmName("naiwlckohqnynkfq")
    public suspend fun siteReference(`value`: Output<ReferencedResourceArgs>) {
        this.siteReference = value
    }

    /**
     * @param value The goal state of the site network service resource. This has references to the configuration group value objects that describe the desired state of the site network service.
     */
    @JvmName("cdbjhcwretsbdurg")
    public suspend
    fun desiredStateConfigurationGroupValueReferences(`value`: Map<String, ReferencedResourceArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.desiredStateConfigurationGroupValueReferences = mapped
    }

    /**
     * @param argument The goal state of the site network service resource. This has references to the configuration group value objects that describe the desired state of the site network service.
     */
    @JvmName("mvilcjjneorkkmkw")
    public suspend fun desiredStateConfigurationGroupValueReferences(
        vararg
        argument: Pair<String, suspend ReferencedResourceArgsBuilder.() -> Unit>,
    ) {
        val toBeMapped = argument.toList().map { (left, right) ->
            left to
                ReferencedResourceArgsBuilder().applySuspend { right() }.build()
        }.toMap()
        val mapped = of(toBeMapped)
        this.desiredStateConfigurationGroupValueReferences = mapped
    }

    /**
     * @param values The goal state of the site network service resource. This has references to the configuration group value objects that describe the desired state of the site network service.
     */
    @JvmName("fbskndjqgmsqiigj")
    public fun desiredStateConfigurationGroupValueReferences(
        vararg
        values: Pair<String, ReferencedResourceArgs>,
    ) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.desiredStateConfigurationGroupValueReferences = mapped
    }

    /**
     * @param value Managed resource group configuration.
     */
    @JvmName("ukdmunhixvcclufa")
    public suspend
    fun managedResourceGroupConfiguration(`value`: ManagedResourceGroupConfigurationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.managedResourceGroupConfiguration = mapped
    }

    /**
     * @param argument Managed resource group configuration.
     */
    @JvmName("mwctqixjefcklgpq")
    public suspend
    fun managedResourceGroupConfiguration(argument: suspend ManagedResourceGroupConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = ManagedResourceGroupConfigurationArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.managedResourceGroupConfiguration = mapped
    }

    /**
     * @param value The network service design version resource reference.
     */
    @JvmName("vkpnvwprhrtvtkhf")
    public suspend
    fun networkServiceDesignVersionResourceReference(`value`: Either<OpenDeploymentResourceReferenceArgs, SecretDeploymentResourceReferenceArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.networkServiceDesignVersionResourceReference = mapped
    }

    /**
     * @param value The network service design version resource reference.
     */
    @JvmName("nvssrkkgvyjuhddo")
    public
    fun networkServiceDesignVersionResourceReference(`value`: OpenDeploymentResourceReferenceArgs) {
        val toBeMapped = Either.ofLeft<OpenDeploymentResourceReferenceArgs,
            SecretDeploymentResourceReferenceArgs,>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.networkServiceDesignVersionResourceReference = mapped
    }

    /**
     * @param value The network service design version resource reference.
     */
    @JvmName("iulravnglajfcmyk")
    public
    fun networkServiceDesignVersionResourceReference(`value`: SecretDeploymentResourceReferenceArgs) {
        val toBeMapped = Either.ofRight<OpenDeploymentResourceReferenceArgs,
            SecretDeploymentResourceReferenceArgs,>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.networkServiceDesignVersionResourceReference = mapped
    }

    /**
     * @param value The site details
     */
    @JvmName("ulmrbdllsnaxayyl")
    public suspend fun siteReference(`value`: ReferencedResourceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.siteReference = mapped
    }

    /**
     * @param argument The site details
     */
    @JvmName("vgmwaxgabvnuhkim")
    public suspend fun siteReference(argument: suspend ReferencedResourceArgsBuilder.() -> Unit) {
        val toBeMapped = ReferencedResourceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.siteReference = mapped
    }

    internal fun build(): SiteNetworkServicePropertiesFormatArgs =
        SiteNetworkServicePropertiesFormatArgs(
            desiredStateConfigurationGroupValueReferences = desiredStateConfigurationGroupValueReferences,
            managedResourceGroupConfiguration = managedResourceGroupConfiguration,
            networkServiceDesignVersionResourceReference = networkServiceDesignVersionResourceReference,
            siteReference = siteReference,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/hybridnetwork/kotlin/inputs/SiteNetworkServicePropertiesFormatArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridnetwork.kotlin.inputs

import com.pulumi.azurenative.hybridnetwork.inputs.SiteNetworkServicePropertiesFormatArgs.builder
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Site network service properties.
 * @property desiredStateConfigurationGroupValueReferences The goal state of the site network service resource. This has references to the configuration group value objects that describe the desired state of the site network service.
 * @property managedResourceGroupConfiguration Managed resource group configuration.
 * @property networkServiceDesignVersionResourceReference The network service design version resource reference.
 * @property siteReference The site details
 */
public data class SiteNetworkServicePropertiesFormatArgs(
    public val desiredStateConfigurationGroupValueReferences:
    Output<Map<String, ReferencedResourceArgs>>? = null,
    public val managedResourceGroupConfiguration: Output<ManagedResourceGroupConfigurationArgs>? =
        null,
    public val networkServiceDesignVersionResourceReference:
    Output<Either<OpenDeploymentResourceReferenceArgs, SecretDeploymentResourceReferenceArgs>>? =
        null,
    public val siteReference: Output<ReferencedResourceArgs>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.hybridnetwork.inputs.SiteNetworkServicePropertiesFormatArgs> {
    override fun toJava():
        com.pulumi.azurenative.hybridnetwork.inputs.SiteNetworkServicePropertiesFormatArgs =
        com.pulumi.azurenative.hybridnetwork.inputs.SiteNetworkServicePropertiesFormatArgs.builder()
            .desiredStateConfigurationGroupValueReferences(
                desiredStateConfigurationGroupValueReferences?.applyValue({ args0 ->
                    args0.map({ args0 -> args0.key.to(args0.value.let({ args0 -> args0.toJava() })) }).toMap()
                }),
            )
            .managedResourceGroupConfiguration(
                managedResourceGroupConfiguration?.applyValue({ args0 ->
                    args0.let({ args0 -> args0.toJava() })
                }),
            )
            .networkServiceDesignVersionResourceReference(
                networkServiceDesignVersionResourceReference?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0.let({ args0 -> args0.toJava() }) }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .siteReference(siteReference?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [SiteNetworkServicePropertiesFormatArgs].
 */
@PulumiTagMarker
public class SiteNetworkServicePropertiesFormatArgsBuilder internal constructor() {
    private var desiredStateConfigurationGroupValueReferences:
        Output<Map<String, ReferencedResourceArgs>>? = null

    private var managedResourceGroupConfiguration: Output<ManagedResourceGroupConfigurationArgs>? =
        null

    private var networkServiceDesignVersionResourceReference:
        Output<Either<OpenDeploymentResourceReferenceArgs, SecretDeploymentResourceReferenceArgs>>? =
        null

    private var siteReference: Output<ReferencedResourceArgs>? = null

    /**
     * @param value The goal state of the site network service resource. This has references to the configuration group value objects that describe the desired state of the site network service.
     */
    @JvmName("ferfdtffverygnnu")
    public suspend
    fun desiredStateConfigurationGroupValueReferences(`value`: Output<Map<String, ReferencedResourceArgs>>) {
        this.desiredStateConfigurationGroupValueReferences = value
    }

    /**
     * @param value Managed resource group configuration.
     */
    @JvmName("tqfdxwykyrcqwgji")
    public suspend
    fun managedResourceGroupConfiguration(`value`: Output<ManagedResourceGroupConfigurationArgs>) {
        this.managedResourceGroupConfiguration = value
    }

    /**
     * @param value The network service design version resource reference.
     */
    @JvmName("cmpcxdjbvnqswsdw")
    public suspend
    fun networkServiceDesignVersionResourceReference(`value`: Output<Either<OpenDeploymentResourceReferenceArgs, SecretDeploymentResourceReferenceArgs>>) {
        this.networkServiceDesignVersionResourceReference = value
    }

    /**
     * @param value The site details
     */
    @JvmName("tninubcwvouenomx")
    public suspend fun siteReference(`value`: Output<ReferencedResourceArgs>) {
        this.siteReference = value
    }

    /**
     * @param value The goal state of the site network service resource. This has references to the configuration group value objects that describe the desired state of the site network service.
     */
    @JvmName("ukexsaqvtxbuypll")
    public suspend
    fun desiredStateConfigurationGroupValueReferences(`value`: Map<String, ReferencedResourceArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.desiredStateConfigurationGroupValueReferences = mapped
    }

    /**
     * @param argument The goal state of the site network service resource. This has references to the configuration group value objects that describe the desired state of the site network service.
     */
    @JvmName("mcfotqwhumnkkjjs")
    public suspend fun desiredStateConfigurationGroupValueReferences(
        vararg
        argument: Pair<String, suspend ReferencedResourceArgsBuilder.() -> Unit>,
    ) {
        val toBeMapped = argument.toList().map { (left, right) ->
            left to
                ReferencedResourceArgsBuilder().applySuspend { right() }.build()
        }.toMap()
        val mapped = of(toBeMapped)
        this.desiredStateConfigurationGroupValueReferences = mapped
    }

    /**
     * @param values The goal state of the site network service resource. This has references to the configuration group value objects that describe the desired state of the site network service.
     */
    @JvmName("beoybftiuggitfgy")
    public fun desiredStateConfigurationGroupValueReferences(
        vararg
        values: Pair<String, ReferencedResourceArgs>,
    ) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.desiredStateConfigurationGroupValueReferences = mapped
    }

    /**
     * @param value Managed resource group configuration.
     */
    @JvmName("owiebqjxpmuddwhd")
    public suspend
    fun managedResourceGroupConfiguration(`value`: ManagedResourceGroupConfigurationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.managedResourceGroupConfiguration = mapped
    }

    /**
     * @param argument Managed resource group configuration.
     */
    @JvmName("ykfxbsanliriefre")
    public suspend
    fun managedResourceGroupConfiguration(argument: suspend ManagedResourceGroupConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = ManagedResourceGroupConfigurationArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.managedResourceGroupConfiguration = mapped
    }

    /**
     * @param value The network service design version resource reference.
     */
    @JvmName("nrgqaastefagnyvo")
    public suspend
    fun networkServiceDesignVersionResourceReference(`value`: Either<OpenDeploymentResourceReferenceArgs, SecretDeploymentResourceReferenceArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.networkServiceDesignVersionResourceReference = mapped
    }

    /**
     * @param value The network service design version resource reference.
     */
    @JvmName("papmpvvdmdptkglc")
    public
    fun networkServiceDesignVersionResourceReference(`value`: OpenDeploymentResourceReferenceArgs) {
        val toBeMapped = Either.ofLeft<OpenDeploymentResourceReferenceArgs,
            SecretDeploymentResourceReferenceArgs,>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.networkServiceDesignVersionResourceReference = mapped
    }

    /**
     * @param value The network service design version resource reference.
     */
    @JvmName("sgklfudtpktvpapp")
    public
    fun networkServiceDesignVersionResourceReference(`value`: SecretDeploymentResourceReferenceArgs) {
        val toBeMapped = Either.ofRight<OpenDeploymentResourceReferenceArgs,
            SecretDeploymentResourceReferenceArgs,>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.networkServiceDesignVersionResourceReference = mapped
    }

    /**
     * @param value The site details
     */
    @JvmName("poibstyvrynkiaih")
    public suspend fun siteReference(`value`: ReferencedResourceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.siteReference = mapped
    }

    /**
     * @param argument The site details
     */
    @JvmName("kajwtypvxpwgobon")
    public suspend fun siteReference(argument: suspend ReferencedResourceArgsBuilder.() -> Unit) {
        val toBeMapped = ReferencedResourceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.siteReference = mapped
    }

    internal fun build(): SiteNetworkServicePropertiesFormatArgs =
        SiteNetworkServicePropertiesFormatArgs(
            desiredStateConfigurationGroupValueReferences = desiredStateConfigurationGroupValueReferences,
            managedResourceGroupConfiguration = managedResourceGroupConfiguration,
            networkServiceDesignVersionResourceReference = networkServiceDesignVersionResourceReference,
            siteReference = siteReference,
        )
}
